==> CGFBApp-1.0.3.tar.gz: CGFBApp/method.install.php <==
<?php
#BEGIN_LICENSE
#-------------------------------------------------------------------------
# Module: CGFBApp (c) 2010 by Robert Campbell 
#         (calguy1000@cmsmadesimple.org)
#  A toolbox of conveniences to build facebook integration into a website
#  for CMS modules and website designers.
# 
#-------------------------------------------------------------------------
# CMS - CMS Made Simple is (c) 2005 by Ted Kulp (wishy@cmsmadesimple.org)
# This project's homepage is: http://www.cmsmadesimple.org
#
#-------------------------------------------------------------------------
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# However, as a special exception to the GPL, this software is distributed
# as an addon module to CMS Made Simple.  You may not use this software
# in any Non GPL version of CMS Made simple, or in any version of CMS
# Made simple that does not indicate clearly and obviously in its admin 
# section that the site was built with CMS Made simple.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
# Or read it online: http://www.gnu.org/licenses/licenses.html#GPL
#
#-------------------------------------------------------------------------
#END_LICENSE

$tmp = file_get_contents(dirname(__FILE__).'/templates/orig_fbinit_async.tpl');
if( $tmp )
  {
    $this->SetTemplate('fbinit_async',$tmp);
  }

$tmp = file_get_contents(dirname(__FILE__).'/templates/orig_fbinit_sync.tpl');
if( $tmp )
  {
    $this->SetTemplate('fbinit_sync',$tmp);
  }

$tmp = file_get_contents(dirname(__FILE__).'/templates/orig_invite.tpl');
if( $tmp )
  {
    $this->SetPreference(CGFBApp::PREF_INVITE_TEMPLATE,'std');
    $this->SetTemplate(CGFBApp::TPL_SYSDFLT_INVITE,$tmp);
    $this->SetTemplate('invite_std',$tmp);
  }
#
# EOF
#
?>

==> CGFBApp-1.0.9.tar.gz: CGFBApp/method.install.php <==
<?php
#BEGIN_LICENSE
#-------------------------------------------------------------------------
# Module: CGFBApp (c) 2010 by Robert Campbell 
#         (calguy1000@cmsmadesimple.org)
#  A toolbox of conveniences to build facebook integration into a website
#  for CMS modules and website designers.
# 
#-------------------------------------------------------------------------
# CMS - CMS Made Simple is (c) 2005 by Ted Kulp (wishy@cmsmadesimple.org)
# This project's homepage is: http://www.cmsmadesimple.org
#
#-------------------------------------------------------------------------
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# However, as a special exception to the GPL, this software is distributed
# as an addon module to CMS Made Simple.  You may not use this software
# in any Non GPL version of CMS Made simple, or in any version of CMS
# Made simple that does not indicate clearly and obviously in its admin 
# section that the site was built with CMS Made simple.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
# Or read it online: http://www.gnu.org/licenses/licenses.html#GPL
#
#-------------------------------------------------------------------------
#END_LICENSE

$tmp = file_get_contents(dirname(__FILE__).'/templates/orig_fbinit_async.tpl');
if( $tmp ) {
  $this->SetTemplate('fbinit_async',$tmp);
}

$tmp = file_get_contents(dirname(__FILE__).'/templates/orig_fbinit_sync.tpl');
if( $tmp ) {
  $this->SetTemplate('fbinit_sync',$tmp);
}

$tmp = file_get_contents(dirname(__FILE__).'/templates/orig_invite.tpl');
if( $tmp ) {
  $this->SetPreference(CGFBApp::PREF_INVITE_TEMPLATE,'std');
  $this->SetTemplate(CGFBApp::TPL_SYSDFLT_INVITE,$tmp);
  $this->SetTemplate('invite_std',$tmp);
}

$tmp = file_get_contents(__DIR__.'/templates/orig_login.tpl');
if( $tmp ) {
  $this->SetPreference(CGFBApp::PREF_LOGIN_TEMPLATE,'std');
  $this->SetTemplate(CGFBApp::TPL_SYSDFLT_LOGIN,$tmp);
  $this->SetTemplate('login_std',$tmp);
}

$tmp = file_get_contents(__DIR__.'/templates/orig_logout.tpl');
if( $tmp ) {
  $this->SetPreference(CGFBApp::PREF_LOGOUT_TEMPLATE,'std');
  $this->SetTemplate(CGFBApp::TPL_SYSDFLT_LOGOUT,$tmp);
  $this->SetTemplate('logout_std',$tmp);
}

$feu = cms_utils::get_module(MOD_FRONTENDUSERS);
$feu->AddPropertyDefn('__'.$this->GetName().'__','',FrontEndUsers::FIELDTYPE_DATA,1024,0,'',0,1);
$feu->SetPropertyDefnExtra('__'.$this->GetName().'__',array('module'=>$this->GetName()));

#
# EOF
#
?>
